@@ -90,13 +90,16 @@ def host_list_extract():
             payload['tag_set_include'] = "qetl-all-hosts"
             payload['tag_set_exclude'] = "qetl-all-ec2,qetl-all-gcp,qetl-all-azure"
 
-        if vm_processed_after != "0":  # Set vm_processed_after to 0 get all assets scanned or un-scanned.
+#        if vm_processed_after != "0":  # Set vm_processed_after to 0 get all assets scanned or un-scanned.
+#            payload['vm_processed_after'] = vm_processed_after
+
+        if not str(vm_processed_after).__contains__("1970"):  # Set to 1970 to remove vm_processed_after and process alldata
             payload['vm_processed_after'] = vm_processed_after
 
         if use_cookie is False:
             headers = {'X-Requested-With': 'qualysetl', 'Authorization': authorization}
         else:
-            headers = {'X-Requested-With': 'qualysetl', 'Cookie': etld_lib_credentials.cookie}
+            headers = {'X-Requested-With': 'qualysetl', 'Cookie': etld_lib_credentials.get_cookie(update_cookie=True)}
 
         etld_lib_functions.logger.info(f"provider     - {provider}")
         etld_lib_functions.logger.info(f"api call     - {url}")
@@ -118,7 +121,7 @@ def host_list_extract():
             payload=payload,
             http_conn_timeout=http_conn_timeout,
             chunk_size_calc=chunk_size_calc,
-            xml_file=xml_file,
+            output_file=xml_file,
             cred_dict=cred_dict,
             qualys_headers_dict=qualys_headers,
             multi_proc_batch_number=multi_proc_batch_number)
@@ -145,7 +148,7 @@ def end_msg_host_list_extract():
 
 def main():
     start_msg_host_list_extract()
-    remove_old_files()
+    # remove_old_files() Hold off on removing old files for restart.
     host_list_extract()
     end_msg_host_list_extract()
 
