@@ -17,6 +17,9 @@ def main():
     etld_lib_spawn_etl.target_module_to_run = etl_knowledgebase.kb_etl_workflow
     etld_lib_spawn_etl.target_method_in_module_to_run = "kb_etl_workflow"
 
+    etld_lib_spawn_etl.etl_dir_to_monitor = etld_lib_config.qetl_user_data_dir
+    etld_lib_spawn_etl.etl_files_max_time_between_changes = 300
+
     etld_lib_spawn_etl.etl_main()
 
 
