@@ -4,7 +4,7 @@ import oschmod
 import re
 import yaml
 from qualys_etl.etld_lib import etld_lib_functions as etld_lib_functions
-from qualys_etl.etld_lib import etld_lib_date_time_functions as api_date
+from qualys_etl.etld_lib import etld_lib_datetime as api_date
 from qualys_etl.etld_lib import etld_lib_sqlite_tables as etld_lib_sqlite_tables
 
 global setup_completed_flag           # Set to true when completed
@@ -44,6 +44,7 @@ global kb_lock_file
 global kb_log_rotate_file
 global kb_table_name
 global kb_csv_truncate_cell_limit
+global kb_data_files
 # USER HOST LIST
 global host_list_data_dir
 global host_list_export_dir
@@ -63,6 +64,7 @@ global host_list_lock_file
 global host_list_log_rotate_file
 global host_list_table_name
 global host_list_csv_truncate_cell_limit
+global host_list_data_files
 # USER HOST LIST DETECTION
 global host_list_detection_data_dir
 global host_list_detection_export_dir
@@ -82,6 +84,29 @@ global host_list_detection_concurrency_limit
 global host_list_detection_multi_proc_batch_size
 global host_list_detection_limit_hosts
 global host_list_detection_table_name
+global host_list_detection_data_files
+
+# USER ASSET INVENTORY
+global asset_inventory_data_dir
+global asset_inventory_export_dir
+global asset_inventory_asset_last_updated
+global asset_inventory_payload_option
+global asset_inventory_json_batch_file
+global asset_inventory_json_dir
+global asset_inventory_shelve_file
+global asset_inventory_sqlite_file
+global asset_inventory_csv_truncate_cell_limit
+global asset_inventory_csv_file
+global asset_inventory_json_file
+global asset_inventory_log_file
+global asset_inventory_lock_file
+global asset_inventory_log_rotate_file
+global asset_inventory_concurrency_limit
+global asset_inventory_multi_proc_batch_size
+global asset_inventory_limit_hosts
+global asset_inventory_table_name
+global asset_inventory_data_files
+global asset_inventory_temp_shelve_file
 
 # Initialize Some Globals
 
@@ -149,6 +174,7 @@ def set_path_qetl_user_home_dir():
     setup_kb_vars()
     setup_host_list_vars()
     setup_host_list_detection_vars()
+    setup_asset_inventory_vars()
 
 
 def create_user_data_dirs():
@@ -374,6 +400,7 @@ def setup_kb_vars():
     global kb_lock_file
     global kb_log_rotate_file
     global kb_table_name
+    global kb_data_files
 
     kb_data_dir = qetl_user_data_dir
     kb_bin_dir = qetl_user_bin_dir
@@ -388,6 +415,8 @@ def setup_kb_vars():
     kb_lock_file = Path(qetl_user_log_dir, ".kb.lock")
     kb_log_rotate_file = Path(qetl_user_log_dir, "kb.1.log")
     kb_table_name = 'Q_KnowledgeBase'
+    kb_data_files = [kb_xml_file, kb_shelve_file, kb_sqlite_file, kb_cve_qid_file, kb_cve_qid_map_shelve, kb_csv_file,
+                     kb_json_file]
 
 
 def get_host_list_user_config():
@@ -461,6 +490,7 @@ def setup_host_list_vars():
     global host_list_lock_file
     global host_list_log_rotate_file
     global host_list_table_name
+    global host_list_data_files
 
     host_list_data_dir = qetl_user_data_dir
     host_list_other_xml_file = Path(host_list_data_dir, "host_list_other_file.xml")
@@ -477,6 +507,9 @@ def setup_host_list_vars():
     host_list_lock_file = Path(qetl_user_log_dir, ".host_list.lock")
     host_list_log_rotate_file = Path(qetl_user_log_dir, "host_list.1.log")
     host_list_table_name = 'Q_Host_List'
+    host_list_data_files = [host_list_other_xml_file, host_list_ec2_xml_file, host_list_gcp_xml_file,
+                            host_list_azure_xml_file, host_list_shelve_file, host_list_sqlite_file,
+                            host_list_csv_file, host_list_json_file]
 
 
 def get_host_list_detection_user_config():
@@ -566,6 +599,7 @@ def setup_host_list_detection_vars():
     global host_list_detection_lock_file
     global host_list_detection_log_rotate_file
     global host_list_detection_table_name
+    global host_list_detection_data_files
 
     host_list_detection_data_dir = Path(qetl_user_data_dir)
     host_list_detection_xml_dir = Path(host_list_detection_data_dir, "host_list_detection_xml_dir")
@@ -578,6 +612,94 @@ def setup_host_list_detection_vars():
     host_list_detection_lock_file = Path(qetl_user_log_dir, ".host_list_detection.lock")
     host_list_detection_log_rotate_file = Path(qetl_user_log_dir, "host_list_detection.1.log")
     host_list_detection_table_name = 'Q_Host_List_Detection'
+    host_list_detection_data_files = [host_list_detection_shelve_file, host_list_detection_sqlite_file,
+                                      host_list_detection_csv_file, host_list_detection_json_file]
+
+
+def get_asset_inventory_user_config():
+    global asset_inventory_data_dir
+    global asset_inventory_export_dir
+    global asset_inventory_asset_last_updated
+    global asset_inventory_payload_option
+    global asset_inventory_concurrency_limit
+    global asset_inventory_multi_proc_batch_size
+    global asset_inventory_limit_hosts
+    global asset_inventory_csv_truncate_cell_limit
+    global qetl_user_config_settings_yaml_file
+    global qetl_manage_user_selected_datetime
+
+    asset_inventory_export_dir = etld_lib_config_settings_yaml_dict.get('asset_inventory_export_dir')
+    asset_inventory_csv_truncate_cell_limit = \
+        etld_lib_config_settings_yaml_dict.get('asset_inventory_csv_truncate_cell_limit')
+    asset_inventory_data_dir = qetl_user_data_dir
+    asset_inventory_asset_last_updated = etld_lib_config_settings_yaml_dict.get('asset_inventory_asset_last_updated')
+    asset_inventory_payload_option = etld_lib_config_settings_yaml_dict.get('asset_inventory_payload_option')
+    asset_inventory_csv_truncate_cell_limit = etld_lib_config_settings_yaml_dict.get('asset_inventory_csv_truncate_cell_limit')
+    if isinstance(asset_inventory_csv_truncate_cell_limit, int):
+        pass
+    else:
+        etld_lib_functions.logger.error(f"asset_inventory_csv_truncate_cell_limit is not an integer, please reconfigure.")
+        etld_lib_functions.logger.error(f"asset_inventory_csv_truncate_cell_limit file: {qetl_user_config_settings_yaml_file}")
+        exit(1)
+
+    asset_inventory_concurrency_limit = etld_lib_config_settings_yaml_dict.get('asset_inventory_concurrency_limit')
+    asset_inventory_multi_proc_batch_size = \
+        etld_lib_config_settings_yaml_dict.get('asset_inventory_multi_proc_batch_size')
+    asset_inventory_limit_hosts = \
+        etld_lib_config_settings_yaml_dict.get('asset_inventory_limit_hosts')
+
+    etld_lib_functions.logger.info(f"asset inventory config - {qetl_user_config_settings_yaml_file}")
+    etld_lib_functions.logger.info(f"asset_inventory_export_dir yaml - {asset_inventory_export_dir}")
+    etld_lib_functions.logger.info(f"asset_inventory_json_dir yaml - {asset_inventory_json_dir}")
+    etld_lib_functions.logger.info(f"asset_inventory_concurrency_limit yaml - {asset_inventory_concurrency_limit}")
+    etld_lib_functions.logger.info(f"asset_inventory_multi_proc_batch_size yaml - {asset_inventory_multi_proc_batch_size}")
+    etld_lib_functions.logger.info(f"asset_inventory_csv_truncate_cell_limit yaml - {asset_inventory_csv_truncate_cell_limit}")
+
+    if qetl_manage_user_selected_datetime is not None:
+        asset_inventory_asset_last_updated = qetl_manage_user_selected_datetime
+        etld_lib_functions.logger.info(f"asset_inventory_asset_last_updated "
+                                       f"set by qetl_manage_user -d option - "
+                                       f"{asset_inventory_asset_last_updated}")
+    elif asset_inventory_asset_last_updated == 'default':
+        asset_inventory_asset_last_updated = api_date.get_utc_date_minus_days(1)
+        etld_lib_functions.logger.info(f"asset_inventory_asset_last_updated default set to  "
+                                       f"utc.now minus 1 days - {asset_inventory_asset_last_updated}")
+    else:
+        etld_lib_functions.logger.info(f"asset_inventory_asset_last_updated yaml - "
+                                       f"{asset_inventory_asset_last_updated}")
+
+
+def setup_asset_inventory_vars():
+    global qetl_user_data_dir
+    global asset_inventory_data_dir
+    global asset_inventory_json_batch_file
+    global asset_inventory_json_dir
+    global asset_inventory_shelve_file
+    global asset_inventory_sqlite_file
+    global asset_inventory_csv_file
+    global asset_inventory_csv_truncate_cell_limit
+    global asset_inventory_json_file
+    global asset_inventory_log_file
+    global asset_inventory_lock_file
+    global asset_inventory_log_rotate_file
+    global asset_inventory_table_name
+    global asset_inventory_data_files
+    global asset_inventory_temp_shelve_file
+
+    asset_inventory_data_dir = Path(qetl_user_data_dir)
+    asset_inventory_json_dir = Path(asset_inventory_data_dir, "asset_inventory_json_dir")
+    asset_inventory_json_batch_file = Path(asset_inventory_json_dir, "asset_inventory_rename_me_to_batch.xml")
+    asset_inventory_temp_shelve_file = Path(asset_inventory_json_dir, "asset_inventory_temp_shelve.db")
+    asset_inventory_shelve_file = Path(asset_inventory_data_dir, "asset_inventory_shelve")
+    asset_inventory_sqlite_file = Path(asset_inventory_data_dir, "asset_inventory_sqlite.db")
+    asset_inventory_csv_file = Path(asset_inventory_data_dir, "asset_inventory.csv")
+    asset_inventory_json_file = Path(asset_inventory_data_dir, "asset_inventory.json")
+    asset_inventory_log_file = Path(qetl_user_log_dir, "asset_inventory.log")
+    asset_inventory_lock_file = Path(qetl_user_log_dir, ".asset_inventory.lock")
+    asset_inventory_log_rotate_file = Path(qetl_user_log_dir, "asset_inventory.1.log")
+    asset_inventory_table_name = 'Q_Asset_Inventory'
+    asset_inventory_data_files = [asset_inventory_shelve_file, asset_inventory_sqlite_file,
+                                  asset_inventory_csv_file, asset_inventory_json_file]
 
 
 def setup_completed():
@@ -607,6 +729,9 @@ def main():
     setup_host_list_detection_vars()
     get_host_list_detection_user_config()
 
+    setup_asset_inventory_vars()
+    get_asset_inventory_user_config()
+
     setup_completed()
 
 
