@@ -104,62 +104,62 @@ def load_json(load_json_file=None, shelve_db=None):
     return count_key_value_pairs_loaded_to_json
 
 
-def extract_json_qualys(
-        try_extract_max_count=3,
-        url=None,
-        headers=None,
-        payload=None,
-        http_conn_timeout=30,
-        chunk_size_calc=20480,
-        json_file=None,
-        cred_dict=None,
-        qualys_headers_dict=None,
-        multi_proc_batch_number=None,
-        extract_validation_type = 'xml'
-
-):
-
-    for _ in range(try_extract_max_count):
-        try:
-            headers['User-Agent'] = f"qualysetl_v{qualys_etl.__version__}"
-            with requests.request("POST", url, stream=True, headers=headers, data=payload, timeout=http_conn_timeout) as r:
-                #  TODO: grab header and check concurrent connections information
-                qualys_headers = get_qualys_headers(r)
-                if multi_proc_batch_number is None:
-                    qualys_headers_dict['batch_000001'] = get_qualys_headers(r)
-                else:
-                    qualys_headers_dict[multi_proc_batch_number] = get_qualys_headers(r)
-
-                etld_lib_functions.logger.info(f"{multi_proc_batch_number}, Qualys Headers: {qualys_headers}")
-                if r.status_code == 200:
-                    with open(json_file, "w", encoding='utf-8') as f:
-                        for chunk in r.iter_content(chunk_size=chunk_size_calc):
-                            try:
-                                f.write(chunk.decode('utf-8'))
-                            except Exception as e:
-                                f.write(etld_lib_functions.remove_low_high_values(chunk).decode('utf-8'))
-                    extract_validation(validation_type=extract_validation_type, output_file_to_validate=output_file)
-                else:
-                    message = get_http_error_code_message_v2_api(str(r.status_code))
-                    etld_lib_functions.logger.error(f"HTTP USER: {cred_dict['username']} url: {url}")
-                    etld_lib_functions.logger.error(f"HTTP {r.status_code}, exiting. message={message}")
-                    if r.status_code == 401 and extract_validation_type == 'json':
-                        pass
-                        # TODO retest login and if successful, retry, else exit
-                    exit(1)
-
-        except Exception as e:
-            etld_lib_functions.logger.warning(f"Warning for extract file: {Path(json_file).name}")
-            etld_lib_functions.logger.warning(f"Warning {e}")
-            etld_lib_functions.logger.warning(f"Retry attempt number: {_ + 1}")
-            time.sleep(60)
-            continue
-        else:
-            break  # success
-    else:
-        etld_lib_functions.logger.error(f"Max retries attempted: {try_extract_max_count}")
-        etld_lib_functions.logger.error(f"extract file: {Path(json_file).name}")
-        exit(1)
+# def extract_json_qualys(
+#         try_extract_max_count=3,
+#         url=None,
+#         headers=None,
+#         payload=None,
+#         http_conn_timeout=30,
+#         chunk_size_calc=20480,
+#         json_file=None,
+#         cred_dict=None,
+#         qualys_headers_dict=None,
+#         multi_proc_batch_number=None,
+#         extract_validation_type = 'xml'
+#
+# ):
+#
+#     for _ in range(try_extract_max_count):
+#         try:
+#             headers['User-Agent'] = f"qualysetl_v{qualys_etl.__version__}"
+#             with requests.request("POST", url, stream=True, headers=headers, data=payload, timeout=http_conn_timeout) as r:
+#                 #  TODO: grab header and check concurrent connections information
+#                 qualys_headers = get_qualys_headers(r)
+#                 if multi_proc_batch_number is None:
+#                     qualys_headers_dict['batch_000001'] = get_qualys_headers(r)
+#                 else:
+#                     qualys_headers_dict[multi_proc_batch_number] = get_qualys_headers(r)
+#
+#                 etld_lib_functions.logger.info(f"{multi_proc_batch_number}, Qualys Headers: {qualys_headers}")
+#                 if r.status_code == 200:
+#                     with open(json_file, "w", encoding='utf-8') as f:
+#                         for chunk in r.iter_content(chunk_size=chunk_size_calc):
+#                             try:
+#                                 f.write(chunk.decode('utf-8'))
+#                             except Exception as e:
+#                                 f.write(etld_lib_functions.remove_low_high_values(chunk).decode('utf-8'))
+#                     extract_validation(validation_type=extract_validation_type, output_file_to_validate=output_file)
+#                 else:
+#                     message = get_http_error_code_message_v2_api(str(r.status_code))
+#                     etld_lib_functions.logger.error(f"HTTP USER: {cred_dict['username']} url: {url}")
+#                     etld_lib_functions.logger.error(f"HTTP {r.status_code}, exiting. message={message}")
+#                     if r.status_code == 401 and extract_validation_type == 'json':
+#                         pass
+#                         # TODO retest login and if successful, retry, else exit
+#                     exit(1)
+#
+#         except Exception as e:
+#             etld_lib_functions.logger.warning(f"Warning for extract file: {Path(json_file).name}")
+#             etld_lib_functions.logger.warning(f"Warning {e}")
+#             etld_lib_functions.logger.warning(f"Retry attempt number: {_ + 1}")
+#             time.sleep(60)
+#             continue
+#         else:
+#             break  # success
+#     else:
+#         etld_lib_functions.logger.error(f"Max retries attempted: {try_extract_max_count}")
+#         etld_lib_functions.logger.error(f"extract file: {Path(json_file).name}")
+#         exit(1)
 
 
 def extract_validation(validation_type='xml', output_file_to_validate=None):
