@@ -3,6 +3,9 @@ import multiprocessing
 import shutil
 import sys
 import time
+import re
+from pathlib import Path
+from datetime import datetime
 import timeit
 from contextlib import redirect_stdout, redirect_stderr
 
@@ -24,6 +27,10 @@ global log_file_path
 global log_file_rotate_path
 global lock_file
 global log_dir
+global etl_dir_to_monitor
+global etl_files_mtime_dict
+global etl_files_max_time_between_changes
+global etl_file_stalled
 
 
 def spawn_etl_in_background_with_arg(args_list=[], max_proc=None):
@@ -49,29 +56,21 @@ def spawn_etl_in_background_with_arg(args_list=[], max_proc=None):
         spawn_process_list.append(spawned_process)
 
 
-#    spawned_process = multiprocessing.Process(target=target_module_to_run, name=target_method_in_module_to_run)
-#    spawned_process.start()
-#    etld_lib_functions.logger.info("Spawned ETL in Background")
-#    spawned_process_start_time = timeit.default_timer()
-#    spawned_process_status_count = 0
-#
-#    while spawned_process.is_alive():
-#        spawned_process_report_status()
-#
-#    spawned_process_gracefully_ended()
-#    time.sleep(1)
-
-
 def spawn_etl_in_background():
     global spawned_process
     global spawned_process_start_time
     global spawned_process_status_count
+    global etl_dir_to_monitor
+    global etl_files_mtime_dict
+    etl_files_mtime_dict = {}
 
     spawned_process = multiprocessing.Process(target=target_module_to_run, name=target_method_in_module_to_run)
     spawned_process.start()
     etld_lib_functions.logger.info("Spawned ETL in Background")
     spawned_process_start_time = timeit.default_timer()
     spawned_process_status_count = 0
+    etl_initial_file_for_monitoring = Path(etl_dir_to_monitor, str(target_method_in_module_to_run))
+    Path.touch(etl_initial_file_for_monitoring, exist_ok=True)
 
     while spawned_process.is_alive():
         spawned_process_report_status()
@@ -80,6 +79,53 @@ def spawn_etl_in_background():
     time.sleep(1)
 
 
+def etl_files_are_stalled():
+    global etl_dir_to_monitor
+    global etl_files_max_time_between_changes
+    global etl_file_stalled
+    etl_files_max_time_exceeded_flag = True
+    etl_files = Path(etl_dir_to_monitor).glob('**/*')
+    vm_workflow = \
+        re.fullmatch(r"^.*(kb_etl_workflow|host_list_etl_workflow|host_list_detection_etl_workflow).*$",
+                     str(target_method_in_module_to_run))
+    asset_inventory_workflow = \
+        re.fullmatch(r"^.*(asset_inventory_etl_workflow).*$",
+                     str(target_method_in_module_to_run))
+    if vm_workflow:
+        workflow_pattern = re.compile(r"^.*(/kb|/host_list).*$")
+    elif asset_inventory_workflow:
+        workflow_pattern = re.compile(r"^.*(/asset_inventory).*$")
+    else:
+        workflow_pattern = re.compile(r"^ERROR$")
+        etld_lib_functions.logger.error("Could not determine workflow type.")
+        etld_lib_functions.logger.error("Please investigate.")
+        exit(1)
+
+    try:
+        for etl_file_path in etl_files:
+            if Path(etl_file_path).is_file():
+                workflow_pattern_match = re.fullmatch(workflow_pattern, str(Path(etl_file_path)))
+                if workflow_pattern_match:
+                    mtime = int(Path(etl_file_path).stat().st_mtime)
+                    datetime_now = datetime.now().timestamp()
+                    datetime_diff = datetime_now - mtime
+                    if datetime_diff < etl_files_max_time_between_changes:
+                        etl_files_max_time_exceeded_flag = False
+                        break  # Files have changed, break and continue.
+                    else:
+                        etl_file_stalled = Path(etl_file_path)
+    except Exception as e:
+        etl_files_max_time_exceeded_flag = True
+        etld_lib_functions.logger.error(f"Could not determine file paths for monitoring: {etl_dir_to_monitor}")
+        etld_lib_functions.logger.error(f"Please investigate Error: {e}.")
+        exit(1)
+
+    if etl_files_max_time_exceeded_flag:
+        etld_lib_functions.logger.info(f"{str(target_method_in_module_to_run)} is stalled.")
+
+    return etl_files_max_time_exceeded_flag
+
+
 def spawned_process_report_status():
     now = timeit.default_timer()
     run_time = (now - spawned_process_start_time)
@@ -98,16 +144,31 @@ def spawned_process_gracefully_ended():
 
 def spawned_process_status_update():
     global spawned_process_status_count
-
     time.sleep(spawned_process_sleep_time)
     if spawned_process_status_count > spawned_process_count_to_status_update or spawned_process_status_count == 0:
         etld_lib_functions.logger.info(f"Job PID {str(spawned_process.pid)} {target_module_to_run.__name__} "
                              f"job running in background.")
         spawned_process_status_count = 1
+        if etl_files_are_stalled():
+            terminate_spawned_process_due_to_stalled_output()
     else:
         spawned_process_status_count = spawned_process_status_count + 1
 
 
+def terminate_spawned_process_due_to_stalled_output():
+    etld_lib_functions.logger.error(f"Stalled Error: {etl_files_max_time_between_changes:,.0f} Seconds Exceeded")
+    etld_lib_functions.logger.error(f"Directory:     {etl_dir_to_monitor} Directory monitored for changes.")
+    etld_lib_functions.logger.error(f"Please review previous extract function name in log to identify the "
+                                    f"stalling program.")
+    etld_lib_functions.logger.error(f"Use api options from the logs to create curl command to simulate issue.")
+    etld_lib_functions.logger.error(f"Provide feedback to your Qualys TAM to assist with engaging support "
+                                    f"if problem persists.")
+    etld_lib_functions.logger.error(f"Terminating job.")
+    spawned_process.terminate()
+    spawned_process.join()
+    exit(1)
+
+
 def terminate_spawned_process():
     etld_lib_functions.logger.error(f"Max Run Time: {spawned_process_max_run_time:,.0f} Seconds Exceeded")
     etld_lib_functions.logger.error(f"Please review for issues that are slowing down the program.")
